@@ -1082,6 +1082,7 @@ class Database:
                 result = json.loads(json.loads(response.content).replace("'", "\""))
 
                 df = pd.DataFrame(result)
+                df['code'] = df['code'].astype(str)
                 df['code'] = df['code'].str.zfill(5)
 
                 return df
@@ -1984,6 +1985,51 @@ def get_hk_holiday_and_expiry_date(start_year, end_year, format='int', str_forma
     dict1 = {'expiry_date': expiry_date_list, 'public_holiday': holiday_list, 'half_day_mkt': half_day_mkt_list}
     return dict1
 
+
+def get_current_us_holiday(format='int', str_format='%Y%m%d'):
+    url = 'https://www.nasdaqtrader.com/Trader.aspx?id=Calendar'
+    headers = {
+        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.193 Safari/537.36'}
+    r = requests.get(url, headers=headers)
+    r.raise_for_status()
+    r.encoding = r.apparent_encoding
+    text = r.text
+
+    soup = BeautifulSoup(text, 'lxml')
+
+    ths = soup.find('table').find_all('th')
+    cols = []
+    for th in ths:
+        text = th.text
+        cols.append(text)
+
+    data = []
+    trs = soup.find('table').find_all('tr')
+    for tr in trs:
+        info = []
+        tds = tr.find_all('td')
+        for td in tds:
+            text = td.text
+            info.append(text)
+        if len(info) > 0:
+            data.append(info)
+    df = pd.DataFrame(data)
+    df.columns = ['date', 'holiday', 'status']
+    df = df.loc[df['status'] == 'Closed']
+
+    us_holiday_list = []
+    date_list = df['date'].to_list()
+    for holiday in date_list:
+        if format == 'dt':
+            us_holiday_list.append(datetime.datetime.strptime(holiday, '%B %d, %Y').date())
+        elif format == 'str':
+            us_holiday_list.append(datetime.datetime.strptime(holiday, '%B %d, %Y').strftime(str_format))
+        elif format == 'int':
+            us_holiday_list.append(int(datetime.datetime.strptime(holiday, '%B %d, %Y').strftime(str_format)))
+
+    return us_holiday_list
+
+
 def response_check(response):
     response_ok = True
 
